@@ -901,7 +901,7 @@ class BaseExperiment:
                             info = {val_metric : best_val}
         if not fetch_only_dir:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}' 
-            extension_candidates = [".ckpt", ".sav"]
+            extension_candidates = ["ckpt", "sav"]
             for ckpt_dir in os.listdir(ckpt_path):
                 ckpt_extension_type = str(ckpt_dir).split('.')[-1]
                 if ckpt_extension_type not in extension_candidates:
@@ -917,7 +917,7 @@ class BaseExperiment:
                 return best_ckpt, info
         else:
             ckpt_path = f'{self.log_path}/checkpoints/{model_type}/{best_model_metadata}/{best_version}'
-            extension_candidates = [".ckpt", ".sav"]
+            extension_candidates = ["ckpt", "sav"]
             for ckpt_dir in os.listdir(ckpt_path):
                 if os.path.exists(ckpt_dir):
                     ckpt_dir = ckpt_dir
