@@ -114,7 +114,10 @@ class BaseNet(pl.LightningModule):
             self.log('train/loss', loss)
             return {'loss' : loss}
         else: # classification
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.long())
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.long())
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.float())
 
             self.log('train/loss', loss)
             self.log('train/acc', acc)
@@ -158,8 +161,10 @@ class BaseNet(pl.LightningModule):
             self.log('predict/loss', loss)
             return {'loss' : loss}
         else:    
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
             self.log('predict/loss', loss)
             self.log('predict/acc', acc)
             self.log('predict/auc', auc)
@@ -180,8 +185,10 @@ class BaseNet(pl.LightningModule):
             self.log('test/loss', loss)
             return {'loss' : loss}
         else:    
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
             self.log('test/loss', loss)
             self.log('test/acc', acc)
             self.log('test/auc', auc)
@@ -341,8 +348,10 @@ class ConvNet(pl.LightningModule):
             self.log('train/loss', loss)
             return {'loss' : loss}
         else:    
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
             self.log('train/loss', loss)
             self.log('train/acc', acc)
             self.log('train/auc', auc)
@@ -358,7 +367,10 @@ class ConvNet(pl.LightningModule):
             self.log('val/loss', loss)
             return {'loss' : loss}
         else:    
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
 
             self.log('val/loss', loss)
             self.log('val/acc', acc)
@@ -374,8 +386,10 @@ class ConvNet(pl.LightningModule):
             self.log('pred/loss', loss)
             return {'loss' : loss}
         else:    
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
             self.log('pred/loss', loss)
             self.log('pred/acc', acc)
             self.log('pred/auc', auc)
@@ -390,8 +404,10 @@ class ConvNet(pl.LightningModule):
             self.log('test/loss', loss)
             return {'loss' : loss}
         else:    
-            loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
-
+            if self.n_classes > 2:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.LongTensor))
+            else:
+                loss, acc, auc = self.criterion(Yhat.squeeze(), y_batch.type(torch.FloatTensor))
             self.log('test/loss', loss)
             self.log('test/acc', acc)
             self.log('test/auc', auc)
